// Copyright 2022 Datafuse Labs.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

use metrics::gauge;
use metrics::increment_gauge;

macro_rules! key {
    ($key: literal) => {
        concat!("cache_", $key)
    };
}

pub fn metrics_inc_memory_cache_access_count(c: u64) {
    increment_gauge!(key!("memory_access_count"), c as f64);
}

pub fn metrics_inc_memory_cache_miss_count(c: u64) {
    increment_gauge!(key!("memory_miss_count"), c as f64);
}

// When cache miss, load time cost.
pub fn metrics_inc_memory_cache_miss_load_millisecond(c: u64) {
    increment_gauge!(key!("memory_miss_load_millisecond"), c as f64);
}

pub fn metrics_inc_memory_cache_hit_count(c: u64) {
    increment_gauge!(key!("memory_hit_count"), c as f64);
}

pub fn metrics_reset() {
    let c = 0 as f64;

    gauge!(key!("memory_access_count"), c);
    gauge!(key!("memory_miss_count"), c);
    gauge!(key!("memory_miss_load_millisecond"), c);
    gauge!(key!("memory_hit_count"), c);
}
